;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x8b9b6ebff710c0ae56e4950a7bdb1775 . "./code.cg2js/cg-common-control.fasl")
(#x958f2cfa359c09139c944f185ee15abd . "./code.cg2js/cg-clipboard-stack.fasl")
(#x8b467186391711dc38a9c9545364382a . "./code.cg2js/cg-yes-no-string.fasl")
(#x2ddc9a5da0cc09cf0fe06f793159cc1f . "./code.cg2js/cg-clipboard.fasl")
(#x34e8f870fe64b205b5e785531400bdce . "./code.cg2js/cg-dde-utils.fasl")
(#xb03e0e5f426278099d0ede19771f7e57 . "./code.cg2js/cg-editable-text.fasl")
(#x4033e4e8a2d653dcf16dc4525c380b3a . "./code.cg2js/cg-text-or-combo.fasl")
(#x6262c86fcd303a6bda2186a6352dd814 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x0c02ad24bd4ed9f25d3539caa84897d2 . "./code.cg2js/cg-graphics-context.fasl")
(#x178fcbc8510888467040dc288c31f2b0 . "./code.cg2js/cg-choose-printer.fasl")
(#xfea5b4989f231853147583c0665ee53b . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x9f4ad1e63b33fe67272f3405df22863b . "./code.cg2js/cg-edit-in-place.fasl")
(#x73c607936480683d4125232b721dd318 . "./code.cg2js/cg-split-bar.fasl")
(#x3073612a1df3902f508b379f35d053cf . "./code.cg2js/cg-timer.fasl")
(#xc0dad6babb7fcda31aea485818b09a94 . "./code.cg2js/cg-progress-indicator.fasl")
(#x85cbeb46a26531fd4dd46f5dbefb2e87 . "./code.cg2js/cg-object-editor.fasl")
(#xe19cc0da8833ca6e4e1666394bcf74c0 . "./code.cg2js/cg-fill-texture.fasl")
(#x41627e51881ddb6b898d27f5428d9845 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x17e27732a9a3427f2ea1023e43d80e69 . "./code.cg2js/cg-os-window.fasl")
(#xf90ae1b6908fa3199ae8c0b7079dcc58 . "./code.cg2js/cg-color-dialog.fasl")
(#xf5f57e8b812a3d89a1f77ff78ddc6927 . "./code.cg2js/cg-combo-box.fasl")
(#xd72f4ab82c7b03115d03f4c235736788 . "./code.cg2js/cg-directory-dialog.fasl")
(#x6752dec690fb483c1fc11c04bc586a87 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x047f63fae2b457fdd1d7a19529ba626d . "./code.cg2js/cg-tooltip.fasl")
(#x8b9434cc814acdfd5bab7e13e6fde789 . "./code.cg2js/cg-lettered-menu.fasl")
(#x890ba504dc953bd93f87b7cbe141d9a2 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x27f30aca4b171b2826e1b76b7ed99eb4 . "./code.cg2js/cg-pixmap.fasl")
(#xcbec3f22d3d5b3f025714471dcb91112 . "./code.cg2js/cg.fasl")
(#x77d20dbe8e30ed6ee88b587c3c308c1e . "./code.cg2js/cg-class-slot-grid.fasl")
(#x54fc9919f4a22684c1a4ef3aa1791c87 . "./code.cg2js/cg-template-string.fasl")
(#xd1659d4c386feacf59af74a9c8fe99d8 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x37f86c8b76bade48729d1c7e58f7c9d6 . "./code.cg2js/cg-check-box.fasl")
(#xe37329fea42d5281528a6a65a838c7f1 . "./code.cg2js/cg-toggling-widget.fasl")
(#xd7a1d5b89d4254c1205b21a2019d06fd . "./code.cg2js/cg-radio-button.fasl")
(#x652cb56fe87982ae409b4f96e413688e . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xa1599c1e64840f751aa75e2477ad4291 . "./code.cg2js/cg-scaling-stream.fasl")
(#x9a84fa7cf1d9db3bbb485cacd0c8703b . "./code.cg2js/cg-multi-picture-button.fasl")
(#x047f47081d6998f97e3ba7e2626e934a . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x45e5d3d8301c27ba51d9a2befc85cfa1 . "./code.cg2js/cg-grid-widget.fasl")
(#x95ef4036e7e752698985cbb5732acb6f . "./code.cg2js/cg-text-edit-pane.fasl")
(#x8a663d20fdce0c40ad6fbfd6bc9ba9b6 . "./code.cg2js/cg-item-list.fasl")
(#xde8d9ab30dcfe79701941722e948e2c3 . "./code.cg2js/cg-paren-matching.fasl")
(#x9782546e36fc5242648f872acd5e5620 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xdfed0bdf79e8d0acbf33fde7b93f6cd5 . "./code.cg2js/cg-html-dialog.fasl")
(#x54c3ef98dc9e96ceee265620935a8928 . "./code.cg2js/cg-pixmap-widget.fasl")
(#x7f75e4fe4e02d107dd7ea1d2449a4251 . "./code.cg2js/cg-project-window.fasl")
(#x6c5c2db9ea2d9eb7c41e6ae7a9e8cb32 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x7b893b91d0eb63f48fa097b05d226683 . "./code.cg2js/cg-toolbar.fasl")
(#xda790f127eb5169eee119e96fdda5e36 . "./code.cg2js/cg-caret.fasl")
(#xac53e1c2ca231aa60f79c350a19501d4 . "./code.cg2js/cg-scroll-bar.fasl")
(#x90a1ac746b0dd2606e63602fce83fbbb . "./code.cg2js/cg-web-browser.fasl")
(#x497a81bd5dc0b71d1add2806815c5760 . "./code.cg2js/cg-dropping-outline.fasl")
(#x105a75d608ecd850991e00cb4105ff42 . "./code.cg2js/cg-font-dialog.fasl")
(#x45576d78d0e07675b9da26e682fee319 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x56c12e1af1b66751d14db3ee5ff019a7 . "./code.cg2js/cg-yes-no-list.fasl")
(#xb09e3dd6ad5f0a3b8316ce63c2434b07 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x233d805fa48fccff2a7132f1552174f1 . "./code.cg2js/cg-lamp.fasl")
(#x495e3040a7e038b28f96f6e55f8208bd . "./code.cg2js/cg-drawable.fasl")
(#x7d48fe760ab52daf5a476e185637cd40 . "./code.cg2js/cg-choice-list.fasl")
(#xf7fe0f4a7b15fe702357bfd0a21a3eb4 . "./code.cg2js/cg-curve.fasl")
(#x23aa22c929f08da02d5d4092a8df2322 . "./code.cg2js/cg-base.fasl")
(#xda3f2a63e126b4f0929f257443743f29 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x5609cbb9edcfc26681410e315be3d756 . "./code.cg2js/cg-printing.fasl")
(#x2b9fd4da10ebd993154bb920a7c0fb8f . "./code.cg2js/cg-chart-or-plot.fasl")
(#x90ac8c0b3d379a0b40f4b7c8cd6fd6df . "./code.cg2js/cg-hotspot.fasl")
(#x30222c3c35eaf31f724d726b94eadb51 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xdfee28050940c2130a63857d0ab897c5 . "./code.cg2js/cg-utility-dialog.fasl")
(#x915505952235f9b090c842fb02da6c4d . "./code.cg2js/cg-shortcut-menu.fasl")
(#x4980a082aa46113b6ef5e06506397759 . "./code.cg2js/cg-comtab.fasl")
(#xf88dbdd3776ec8202f4f5481fdfd42d9 . "./code.cg2js/cg-os-widget.fasl")
(#x0224f22451d54441a03e9021f4604b5b . "./code.cg2js/cg-icon.fasl")
(#x950ff302b0821155b9cf4bedea016740 . "./code.cg2js/cg-dev.fasl")
(#x2d543c6a3736d51ef5ee51d5767a4f66 . "./code.cg2js/cg-calendar.fasl")
(#xa131d7d049276f4534316aac7a36fc8a . "./code.cg2js/cg-group-box.fasl")
(#xe9f8f1417e9bca0fc8fdf918100498fe . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x59c2e7ac6cd4e3c67369f40f776d2353 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xdf4ef5347eba142b3671498dfe50c60b . "./code.cg2js/cg-drag-and-drop.fasl")
(#x87ce6cb802418a16b0c9bfb7c7b24e7e . "./code.cg2js/cg-nodes.fasl")
(#x2bbdf782b8f38c1bd45df48d635fdeba . "./code.cg2js/cg-intersect.fasl")
(#x44d0647f568725ad68ce08e26662f2d8 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x0ef77618bb8016154fdc1f30d2d30469 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x88220391bceb84c1e3b8b8f755d6296c . "./code.cg2js/cg-class-support.fasl")
(#x278ac50bcb86eca927b17eec9a6d392d . "./code.cg2js/cg-dialog-item.fasl")
(#xa94a2539a8b3fcca31e39a7d494526cf . "./code.cg2js/cg-plot-widget.fasl")
(#xbd88e38b3eb75e9c54af7a5e2ab177b8 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x53c2665aeae6ff200bb8ddf91ea1394a . "./code.cg2js/cg-up-down-control.fasl")
(#x68d6cf93dd9bf65b2157d00fe2ca4ce3 . "./code.cg2js/cg-rich-edit.fasl")
(#x57f2c510896b6aae30d0feb51cdb5d00 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xd600bb37ed7f31d79a1200b3ee9303e1 . "./code.cg2js/cg-status-bar.fasl")
(#x4f8ff39a2e853aabd0404a19e798499a . "./code.cg2js/cg-class-grid.fasl")
(#x2dbf171ac40efd8a2faca04cac66527b . "./code.cg2js/cg-wrap-string.fasl")
(#xa53c8ffd2574197b35a6348015a94f09 . "./code.cg2js/cg-layout.fasl")
(#x96f5d35b1fb7d9b24a2f72205c5805ce . "./code.cg2js/cg-lisp-widget.fasl")
(#x8d5d0016b7d999762bbd4db5dfe1e216 . "./code.cg2js/cg-button.fasl")
(#xa695ac3d37cfc792551ddbca02df652d . "./code.cg2js/cg-string-dialog.fasl")
(#x96e99da6333a25d7fd057fdf8f627597 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xd624f44d1ff4311241212b728fc3cf6d . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x854aebbfcb2a4ee84486dfcd267de64a . "./code.cg2js/cg-bitmap-stream.fasl")
(#x45a907478dc1d7325a256e46a2fcb776 . "./code.cg2js/cg-static-text.fasl")
(#xfa994e56a187c2d1d03b5ed5e66fdcae . "./code.cg2js/cg-outline.fasl")
(#x7f48a7ba0ccf6132dc52c5f5f578c8a9 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xeb0dbd975165f7fca1bd9590e6aef744 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x899fafa564386a7d741d8033a739c011 . "./code.cg2js/cg-picture-widget.fasl")
(#x32f8bd0b1914a7e4044020173b85469f . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x7c935354fa4be5c274298e6c73c47cab . "./code.cg2js/cg-chart-widget.fasl")
(#x630a181f4ce4b3be427a61cb81f87892 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x99de704cb0e8547eef716557aa894fe9 . "./code.cg2js/cg-lisp-text.fasl")
(#x2d7ee8c1414c69672bc6d3854e43795e . "./code.cg2js/cg-palette.fasl")
(#x0e89fa6d731035b2bae2e42726577a67 . "./code.cg2js/cg-property.fasl")
(#xcb7ea1e18a5f1a28eddc07bce8b83eeb . "./code.cg2js/cg-intersect-posbox.fasl")
(#x136790dca7eb8fa65e1936e32ea80f35 . "./code.cg2js/cg-file-dialog.fasl")
(#xc3f1bb9e648103a26c6e165a29aa2e31 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xde17b2ffa1722782d6936d6fc6e224ad . "./code.cg2js/cg-get-pixmap.fasl")
(#x942ec878e06bd7b57cc724e105d3fdac . "./code.cg2js/cg-tray.fasl")
(#x83b9d56fed96c4acfcdcd7449fac7995 . "./code.cg2js/cg-acache.fasl")
(#x614332d8c522ed27d98776a7bd921ca3 . "./code.cg2js/cg-message-dialog.fasl")
(#xdd0de41d7f16f49ceb7281fdd2423364 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xdbffd9d9edd8d7cd5ac39b27117468a3 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xd9b0266a197735bcfdc7852d6167bef7 . "./code.cg2js/cg-tab-control.fasl")
(#xdc44c19be4e891a81c36161ebc2e662b . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x7d8d89d08a02d819250bfb79b509fbac . "./code.cg2js/cg-menu-tooltip.fasl")
(#x026e767f1c4057a4963d147945efc199 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x5975eaae13f97d8510434fdbd47fce78 . "./code.cg2js/cg-menu.fasl")
(#xb59ff02018b89c0ca878914a7f7d4dd9 . "./code.cg2js/cg-get-position.fasl")
(#x2bf3581d089fe0b92ecdd8841eb134f8 . "./code.cg2js/cg-trackbar.fasl")
(#xb6a2f8f346c9379cd7675cb8507a8c80 . "./code.cg2js/cg-selected-object.fasl")
(#xc0f631ada38930244c1989c8d020ab40 . "./code.cg2js/cg-list-view.fasl")
(#x73185a77b855b1d1d2709b5a250ab7ca . "./code.cg2js/cg-html-widget.fasl")
(#xae06c2c3c5bf75fd9f22481f2821d4a8 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x704f0c3a7eb8276ff41f27a2a2b5647b . "./code.cg2js/cg-text-widget.fasl")
(#x07f84b6ea49cb03c42963b8c0760dd06 . "./code.idejs/ide-base.fasl")
(#xe5795a3acf0a44f8a27fa3da811e76f3 . "./code.idejs/ide-process-browser.fasl")
(#xa6e5f3058c408a29197ab7b1e6bcd23b . "./code.idejs/ide-patch-dialog.fasl")
(#xc92b044ec4dd36ae5d6035630ef7896f . "./code.idejs/ide-keyshort.fasl")
(#x1ce57fc14013b91f074efb2349e6f374 . "./code.idejs/ide-window-list.fasl")
(#x3adb550c044a5aeb683b62874fc42dd5 . "./code.idejs/ide.fasl")
(#x96973689143eacfcff8fa44d8dcc41ca . "./code.idejs/ide-editor.fasl")
(#x27b0911dd27b2cd750eccb6070e58231 . "./code.idejs/ide-clipboard.fasl")
(#xa380ec35c616ef6e7cdde24abf658aa9 . "./code.idejs/ide-trace.fasl")
(#xddb9494c0c584567c3c796af489e70b4 . "./code.idejs/ide-class-browser.fasl")
(#x4d95a3f2cdd85c97c8760510c687b5cc . "./code.idejs/ide-grapher.fasl")
(#x5830226d4ca00bb4da0c66a35adb1eb8 . "./code.idejs/ide-apropos.fasl")
(#x7a23e1e306e07494083c42111d60bb18 . "./code.idejs/ide-navigator.fasl")
(#x2d860d8ae71b9c1f6f22ecadf2b6387c . "./code.idejs/ide-find-definitions.fasl")
(#xe6a77b8f72029787f65e7494ea3d47b0 . "./code.idejs/ide-project.fasl")
(#x0b3b209dddfc92f5e7dd72f6ead8bd33 . "./code.idejs/ide-class-grapher.fasl")
(#xe04d46ae94fb956aeb28041f04f3f507 . "./code.idejs/ide-acache.fasl")
(#x4808bb16c6a473fa9667fee41753d91d . "./code.idejs/ide-find-in-files.fasl")
(#x9e7f8e128f5d54400d7242f6b574d5f2 . "./code.idejs/ide-inspector.fasl")
(#x3b0d46742f7df28c1862733535274eb7 . "./code.idejs/ide-intro.fasl")
(#xa6944396701e87bc3557708be110f6af . "./code.idejs/ide-package-list.fasl")
(#xa4e5bd367e0264d71ab3c14285f2c694 . "./code.idejs/ide-dev.fasl")
(#xce00500f2b7aa1ccf85b86b65756d56c . "./code.idejs/ide-form.fasl")
(#x696b64509ebe0538a3b58ac1081d4fa0 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
